@@ -14,6 +14,7 @@ module Gemojione
       @emoji_by_code = {}
       @emoji_by_keyword = {}
       @emoji_by_category = {}
+      @emoji_by_unicode = {}
       @all = emoji_list
 
       emoji_list.each do |key, emoji_hash|
@@ -38,6 +39,9 @@ module Gemojione
         moji = emoji_hash['moji']
         @emoji_by_moji[moji] = emoji_hash if moji
 
+        unicode = emoji_hash['unicode']
+        @emoji_by_unicode[unicode] = emoji_hash if unicode
+
         emoji_hash['keywords'].each do |emoji_keyword|
           @emoji_by_keyword[emoji_keyword] ||= []
           @emoji_by_keyword[emoji_keyword] << emoji_hash
@@ -51,7 +55,7 @@ module Gemojione
       end
 
       @emoji_code_regex = /#{@emoji_by_code.keys.map{|ec| Regexp.escape(ec)}.join('|')}/
-      @emoji_moji_regex = /#{@emoji_by_moji.keys.map{|ec| Regexp.escape(ec)}.join('|')}/
+      @emoji_moji_regex = /#{@emoji_by_moji.keys.sort { |a, b| b.length <=> a.length }.map{|ec| Regexp.escape(ec)}.join('|')}/
       @emoji_ascii_regex = /#{@emoji_by_ascii.keys.map{|ec| Regexp.escape(ec)}.join('|')}/
     end
 
@@ -79,6 +83,10 @@ module Gemojione
       @emoji_by_code[shortname]
     end
 
+    def find_by_unicode(unicode)
+      @emoji_by_unicode[unicode]
+    end
+
     def unicode_moji_regex
       @emoji_moji_regex
     end
