@@ -5,6 +5,12 @@ require File.absolute_path File.dirname(__FILE__) + '/test_helper'
 describe Gemojione::Index do
   let(:index) { Gemojione::Index.new }
 
+  describe "all" do
+    it "return emoji_list" do
+      assert index.all, index.instance_variable_get(:@emoji_by_name)
+    end
+  end
+
   describe "find_by_name" do
     it 'should find cyclone emoji' do
       assert index.find_by_name('cyclone')
@@ -33,6 +39,18 @@ describe Gemojione::Index do
       assert index.find_by_ascii('<3')['unicode'] == "2764"
     end
   end
+  
+  describe 'find by shortname' do
+    it 'returns the heart emoji' do
+      assert index.find_by_shortname(':heart:')['unicode'] == '2764'
+    end
+  end
+
+  describe 'find by category' do
+    it 'should find people category by category name' do
+      assert index.find_by_category('people')
+    end
+  end
 
   describe "unicode_moji_regex" do
     it "should return complex moji regex" do
