@@ -15,14 +15,14 @@ describe String, 'with Emoji extensions' do
     it 'should replace named moji with an img tag' do
       base_string = "I :heart: Emoji"
       replaced_string = base_string.with_emoji_names
-      assert_equal "I <img alt=\"❤\" class=\"emoji\" src=\"http://localhost:3000/2764.png\"> Emoji", replaced_string
+      assert_equal "I <img alt=\"heart\" class=\"emoji\" src=\"http://localhost:3000/2764.png\"> Emoji", replaced_string
     end
   end
 
   describe '#image_url' do
     it 'should generate image_url' do
-      assert_equal 'http://localhost:3000/1F300.png', '🌀'.image_url
-      assert_equal 'http://localhost:3000/1F300.png', 'cyclone'.image_url
+      assert_equal 'http://localhost:3000/1f300.png', '🌀'.image_url
+      assert_equal 'http://localhost:3000/1f300.png', 'cyclone'.image_url
     end
   end
 
